/**
  *  \file client/scr-base.cc
  *  \brief Starbase Screen
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/screens.h"
#include "client/actions.h"
#include "client/cscreen.h"
#include "client/dlg-objsel.h"
#include "client/wscanchart.h"
#include "client/tiles/baseoverview.h"
#include "client/tiles/baseorder.h"             // cm_Base_Recycle
#include "game/global.h"
#include "game/planet.h"
#include "int/if/planetif.h"
#include "int/intglobal.h"
#include "int/keymap.h"
#include "ui/msgbox.h"
#include "ui/uiglobal.h"
#include "util/nls.h"

namespace {
    class WBaseScreen : public WControlScreen {
     public:
        WBaseScreen();
        ~WBaseScreen();
        bool handleCommand(const UICommand& cmd, UIBaseWidget& sender);
        void update();
        void setScriptContext();
    };
}

int
chooseBase()
{
    int nbases = global_base_type.getCount();
    if (nbases == 0) {
        messageBox(_("You do not have any starbases. "
                     "To build starbases, use [F8] on a planet."),
                   _("Starbases"));
        return 0;
    } else if (nbases == 1) {
        return global_base_type.getCurrent();
    } else {
        GAliasObjectType aot(global_base_type);
        WBaseOverviewTile bot(aot);
        WObjectSelectionDialog dlg(_("Select Starbase"), "pcc2:unitsel", aot);
        dlg.addWidget(bot);
        dlg.pack();
        ui_root->centerWidget(dlg);
        if (ui_root->runModal(dlg) == cm_Enter)
            return aot.getCurrent();
        else
            return 0;
    }
}

/****************************** WBaseScreen ******************************/

WBaseScreen::WBaseScreen()
    : WControlScreen(global_base_type, WScreenId::BaseScreen)
{
    createTileLayout(*this, "BASESCREEN", global_base_type);
    addChart(holder.add(new WScannerChartWidget()));
    setKeymap(IntKeymap::getKeymapByName("BASESCREEN"));
}

WBaseScreen::~WBaseScreen()
{ }

bool
WBaseScreen::handleCommand(const UICommand& cmd, UIBaseWidget& sender)
{
    if (cmd.code == cm_Base_Recycle) {
        int pid         = getType().getCurrent();
        GUniverse& univ = *getType().getUniverse();
        GPlanet& me     = univ.getPlanet(pid);
        doBaseFixRecycle(univ, me, sender);
        return true;
    }
    return WControlScreen::handleCommand(cmd, sender);
}

void
WBaseScreen::update()
{
    if (GMapObject* mo = dynamic_cast<GMapObject*>(&getType().getObject(getType().getCurrent())))
        getScanner().getChart()->setCenterPosition(mo->getPos());
}

void
WBaseScreen::setScriptContext()
{
    global_contexts.push_back(new IntPlanetContext(getType().getCurrent()));
}

void
doBaseScreen()
{
    return WBaseScreen().runScreen();
}
