/**
  *  \file client/tiles/csheader.cc
  *  \brief WControlScreenHeaderTile tile
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/csheader.h"
#include "ui/uiglobal.h"
#include "ui/util.h"
#include "client/wcolorframe.h"
#include "ui/widgets/imagewidget.h"
#include "ui/widgets/button.h"

/** Constructor.
    \param type object type to observe
    \param buttons the buttons you want to be displayed */
WControlScreenHeaderTile::WControlScreenHeaderTile(GObjectType& type, int buttons)
      // FIXME: magic numbers
    : WObjectTypeObserverTile(GfxPoint(315, 145), type), buttons(buttons)
{
    init();
}

void
WControlScreenHeaderTile::init()
{
    setLayout(LeftJustified, 5, false);
    addControl(GfxRect( 5-5,  45, 30, 25),
               holder.add(new UIButton("F1", SDLK_F1)));
    addControl(GfxRect(40-5,  45, 30, 25),
               holder.add(new UIButton("F2", SDLK_F2)));
    addControl(GfxRect( 5-5,  75, 30, 25),
               holder.add(new UIButton("F3", SDLK_F3)));
    addControl(GfxRect(40-5,  75, 30, 25),
               holder.add(new UIButton("F4", SDLK_F4)));
//     addControl(GfxRect( 5-5, 105, 30, 25),
//                holder.add(new UIButton("F6", SDLK_F6)));
    addControl(GfxRect(40-5, 105, 30, 25),
               holder.add(new UIButton("F7", SDLK_F7)));
    addControl(GfxRect(265-5, 114, 45, 25),
               holder.add(new UIButton("ESC", SDLK_ESCAPE)));
    addControl(GfxRect(230-5, 114, 25, 25),
               holder.add(new UIButton("H", 'h')));
    addControl(GfxRect(285-5, 45, 25, 25),
               holder.add(new UIButton(cm_CS_Xchg, "X", 'x')).addKey());
    addControl(GfxRect(75-5, 45, 20, 25),
               holder.add(new UIButton("\xE2\x86\x91", '-')));
    addControl(GfxRect(75-5, 75, 20, 25),
               holder.add(new UIButton("\xE2\x86\x93", '+')));
//     if (buttons & bSend)
//         addControl(GfxRect(75-5, 105, 20, 25),
//                    holder.add(new UIButton("I", 'i')));
//     if (buttons & bAuto)
//         addControl(GfxRect(230-5, 45, 50, 25),
//                    holder.add(new UIButton("Auto", SDLK_RETURN)));
    if (buttons & bCycle)
        addControl(GfxRect(275-5, 75, 35, 25),
                   holder.add(new UIButton("\xEE\x85\x80", SDLK_TAB)));
    if (buttons & bAdd)
        addControl(GfxRect(230-5, 75, 40, 25),
                   holder.add(new UIButton("Add", SDLK_INSERT)));
    if (buttons & bName)
        addControl(GfxRect(315-20-5, 0, 20, 20),
                   holder.add(new UIButton("N", 'n')));

    // Image
    image_cf = &holder.add(new WColorFrame());
    image = &holder.add(new UIImageWidget(105, 93));
    addControl(GfxRect(108-5, 45, 107, 95), *image_cf);
    image_cf->add(*image);
}

void
WControlScreenHeaderTile::drawData(GfxCanvas& can)
{
    // FIXME: magic numbers
    int wi = (buttons & bName) ? extent.w-20 : extent.w;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.setSolidBackground();

    ctx.setColor(UIColor::tc_Heading);
    ctx.useFont(*fonts[FONT_TITLE]);
    outTextF(ctx, 0, 0, wi, getTitle());

    ctx.setColor(UIColor::tc_Yellow);
    ctx.useFont(*fonts[FONT_NORMAL]);
    outTextF(ctx, 0, 25, extent.w, getSubtitle());

    image->setImage(ResManager::getInstance().getPixmap(getPictureId()));
    image_cf->setColor(getObject()->isMarked() ? cf_Yellow : cf_None);
}
