<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

 <xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" />

 <xsl:template match="/help">
  <xsl:comment>Documentation for PCC2, HTML generated from help file.</xsl:comment>
  <html>
   <head>
    <title>PCC2 Help</title>
    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
     <style type="text/css" title="Standard Style">
   body {
     background: #000000;
     color: #cccccc;
   }
   h1 {
     color: #ffffff;
     border-bottom: solid #ffffff 2px;
     border-right: solid #ffffff 2px;
     background: #444444;
     padding: 0.3em;
   }
   h1:before {
     content: ">> ";
   }
   b {
     color: #ffffff;
   }
   h2 {
     background: #004040;
     color: #80ffff;
     border: solid #40c0c0 2px;
     padding: 0.2em;
   }
   h3 {
     color: #80ffff;
     border-bottom: solid #40c0c0 2px;
     padding: 0.2em;
   }
   a:link {
     color: #aaaaee;
     text-decoration: none;
   }
   a:visited {
     color: #ccccff;
     text-decoration: none;
   }
   /* This makes oh-so-neat keycaps, even better than in PCC 1.x :-) */
   kbd {
     font-variant: small-caps;
     border-style: solid;
     border-width: 1px 2px 2px 1px;
     border-color: #888888 #888888 #666666 #666666;
     /* -moz-border-radius: 2px 2px 2px 2px; */
     padding: 0px 2px 0px 2px;
     background-color: #eeeeee;
     color: #000000;
   }
   /* Avoid consuming too much vertical space for the TOC */
   ul.toc li ul li {
     display: inline;
     white-space: nowrap;
   }
   ul.toc li ul li.first:before {
     content: " [ ";
   }
   ul.toc li ul li:before {
     content: " | ";
   }
   ul.toc li ul li.last:after {
     content: " ] ";
   }
   /* first-in-priority table */
   tr.fp td {
     border-top: solid #888888 1px;
   }
    </style>
   </head>
   <body>
    <h1>PCC2 Help</h1>

    <xsl:apply-templates />
   </body>
  </html>
 </xsl:template>

 <xsl:template match="page">
  <xsl:apply-templates />
 </xsl:template>

 <xsl:template match="h1">
  <h2>
   <xsl:if test="name(..) = 'page'">
    <xsl:attribute name="id"><xsl:value-of select="../@id" /></xsl:attribute>
   </xsl:if>
   <xsl:apply-templates />
  </h2>
 </xsl:template>

 <xsl:template match="h2">
  <h2><xsl:apply-templates /></h2>
 </xsl:template>

 <xsl:template match="h3">
  <h4><xsl:apply-templates /></h4>
 </xsl:template>

 <xsl:template match="p">
  <p><xsl:apply-templates /></p>
 </xsl:template>

 <xsl:template match="ul">
  <ul>
   <xsl:for-each select="li">
    <li><xsl:apply-templates /></li>
   </xsl:for-each>
  </ul>
 </xsl:template>

 <xsl:template match="ol">
  <ol>
   <xsl:for-each select="li">
    <li><xsl:apply-templates /></li>
   </xsl:for-each>
  </ol>
 </xsl:template>

 <xsl:template match="dl">
  <dl>
   <xsl:for-each select="di">
    <dt><xsl:value-of select="@term" /></dt>
    <dd><xsl:apply-templates /></dd>
   </xsl:for-each>
  </dl>
 </xsl:template>
 
 <xsl:template match="kl">
  <ul>
   <xsl:for-each select="ki">
    <li><kbd><xsl:value-of select="@key" /></kbd>: <xsl:apply-templates /></li>
   </xsl:for-each>
  </ul>
 </xsl:template>

 <xsl:template match="b|em|tt|kbd">
  <xsl:element name="{name()}">
   <xsl:apply-templates />
  </xsl:element>
 </xsl:template>

 <xsl:template match="a">
  <a href="#{@href}"><xsl:apply-templates /></a>
 </xsl:template>

</xsl:stylesheet>
